Function ipc_server::client_send

source ·
pub fn client_send<C: IpcServerCommand>(command: &C, socket_path: &str)
Serialize and write the command provided to the UnixStream at the socket_path provided. If there is an active IpcServer, it will receive and process this command upon polling.